Registry

Struct Registry 

pub struct Registry { /* private fields */ }
Registry for managing all structures in polyscope.

Structures are organized by type name and then by instance name.

Implementations

Source

impl Registry

pub fn new() -> Self

Creates a new empty registry.

pub fn register(&mut self, structure: Box<dyn Structure>) -> Result<()>

Registers a structure with the registry.

Returns an error if a structure with the same type and name already exists.

pub fn get(&self, type_name: &str, name: &str) -> Option<&dyn Structure>

Gets a reference to a structure by type and name.

pub fn get_mut( &mut self, type_name: &str, name: &str, ) -> Option<&mut Box<dyn Structure>>

Gets a mutable reference to a structure by type and name.

pub fn contains(&self, type_name: &str, name: &str) -> bool

Checks if a structure with the given type and name exists.

pub fn remove( &mut self, type_name: &str, name: &str, ) -> Option<Box<dyn Structure>>

Removes a structure by type and name.

pub fn remove_all_of_type(&mut self, type_name: &str)

Removes all structures of a given type.

pub fn clear(&mut self)

Removes all structures from the registry.

pub fn iter(&self) -> impl Iterator<Item = &dyn Structure>

Returns an iterator over all structures.

pub fn iter_mut(&mut self) -> impl Iterator<Item = &mut Box<dyn Structure>> + '_

Returns a mutable iterator over all structures.

pub fn len(&self) -> usize

Returns the total number of registered structures.

pub fn is_empty(&self) -> bool

Returns true if the registry is empty.

pub fn get_all_of_type( &self, type_name: &str, ) -> impl Iterator<Item = &dyn Structure>

Returns all structures of a given type.