Group structure for organizing structures hierarchically.
Groups allow organizing structures into a tree hierarchy. When a group is disabled, all of its child structures and groups are also hidden.
Structs
- Group
- A group that can contain structures and other groups.