Structure trait and related types.
A Structure represents a geometric object in the scene, such as a point cloud,
surface mesh, or curve network.
Traits
- HasQuantities
- A structure that can have quantities attached to it.
- Render
Context - Trait for render context - will be implemented in polyscope-render.
- Structure
- A geometric object that can be visualized in polyscope.